<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>Megkettőzés</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>Kiterjesztés</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>Megjelenítés csak a %1-n</translation>
    </message>
</context>
</TS>